Modules
Functions
- Deletes the credential with the specified target name. If the operation fails for any reason, the result will resolve to an error.
- Reads the credential with the specified target name. If the operation fails for any reason, including no credential existing, the result will resolve to an error.
- Writes out the credential with the specified target name. If the operation fails for any reason, the result will resolve to an error.